@@ -2,6 +2,7 @@ from .exception import PipelineError
 from .message import Message
 from .tap import DestinationTap, SourceTap, SourceOf, DestinationOf
 from .worker import Generator, Processor, Splitter
+from .data import DataReaderOf, DataWriterOf
 from .utils import parse_kind
 
 
@@ -16,4 +17,6 @@ __all__ = [
     'Splitter',
     'Message',
     'parse_kind',
+    'DataReaderOf',
+    'DataWriterOf',
 ]
